@@ -97,13 +97,13 @@ int GetKeywordCode (PSTR szKeyword, PINT pfContext)
 {
   PKM pkm = &vrgkmKeywordMap[0];
   
-  while (*pkm->szKeyword && strcmp (szKeyword, pkm->szKeyword))
+  while (*pkm->szKeyword && strcmp(szKeyword, pkm->szKeyword))
     pkm++;
   
   if (pfContext)
     *pfContext = pkm->fContext; /* Set iContext flag */
 
-  return (pkm->iKWCode); /* Return Keyword Code or 0 */
+  return(pkm->iKWCode); /* Return Keyword Code or 0 */
 
 } /* GetKeywordCode */
 
@@ -121,27 +121,27 @@ void GetVarList (PINPUTBUF pibIn, PSTR szLex, int iKWCode)
   PSTRLEX szPunct, szTmp;
          
   do { /* Read model var-list */
-    NextLex (pibIn, szLex, &iLexType);
+    NextLex(pibIn, szLex, &iLexType);
 
     if (iLexType & LX_IDENTIFIER) { /* identifier found */
-      if (GetPunct (pibIn, szPunct, '[')) { /* array */
-        GetArrayBounds (pibIn, &iLB, &iUB);
+      if (GetPunct(pibIn, szPunct, '[')) { /* array */
+        GetArrayBounds(pibIn, &iLB, &iUB);
         for (i = iLB; i < iUB; i++) {
-          sprintf (szTmp, "%s_%ld", szLex, i); /* create names */
-          DeclareModelVar (pibIn, szTmp, iKWCode);
+          sprintf(szTmp, "%s_%ld", szLex, i); /* create names */
+          DeclareModelVar(pibIn, szTmp, iKWCode);
         }
       }
       else { /* simple var */
         /* push back szPunct */
         *pibIn->pbufCur--;
-        DeclareModelVar (pibIn, szLex, iKWCode);
+        DeclareModelVar(pibIn, szLex, iKWCode);
       }
     }
     else { /* not an identifier, should be ',' or '}' */
       if ((szLex[0] != ',') && (szLex[0] != CH_RBRACE)) {
         iErr = szPunct[1] = CH_RBRACE;
-        ReportError (pibIn, RE_EXPECTED | RE_FATAL, szPunct,
-                     "* List must be comma-delimited and end with }.");
+        ReportError(pibIn, RE_EXPECTED | RE_FATAL, szPunct,
+                    "* List must be comma-delimited and end with }.");
       }
     }              
   } while ((szLex[0] != CH_RBRACE) && (!iErr));
@@ -165,40 +165,40 @@ void ProcessDTStatement (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, int iKWCode)
 
   pinfo = (PINPUTINFO) pibIn->pInfo;
 
-  if (!GetFuncArgs (pibIn, 1, &iArgType, szLex, &iLB, &iUB))
-    ReportError (pibIn, RE_BADSTATE | RE_FATAL, szLex, NULL);
+  if (!GetFuncArgs(pibIn, 1, &iArgType, szLex, &iLB, &iUB))
+    ReportError(pibIn, RE_BADSTATE | RE_FATAL, szLex, NULL);
 
-  if (!GetPunct (pibIn, szPunct, '=')) { /* no assignment */
-    ReportError (pibIn, RE_LEXEXPECTED, "=", NULL);
+  if (!GetPunct(pibIn, szPunct, '=')) { /* no assignment */
+    ReportError(pibIn, RE_LEXEXPECTED, "=", NULL);
   }
 
   if (iUB == -1) { /* scalar */
     /* check this is a declared state */
-    if (GetVarType (pinfo->pvmGloVars, szLex) != ID_STATE)
-      ReportError (pibIn, RE_BADSTATE | RE_FATAL, szLex, NULL);
+    if (GetVarType(pinfo->pvmGloVars, szLex) != ID_STATE)
+      ReportError(pibIn, RE_BADSTATE | RE_FATAL, szLex, NULL);
 
     /* read assignment */
-    GetStatement (pibIn, szEqn);
-    UnrollEquation (pibIn, 0, szEqn, szEqnU);
-    DefineVariable (pibIn, szLex, szEqnU, iKWCode);
+    GetStatement(pibIn, szEqn, iKWCode);
+    UnrollEquation(pibIn, 0, szEqn, szEqnU);
+    DefineVariable(pibIn, szLex, szEqnU, iKWCode);
   }
   else { /* array */
     /* read assignment */
-    GetStatement (pibIn, szEqn);
+    GetStatement(pibIn, szEqn, iKWCode);
     for (i = iLB; i < iUB; i++) {
-      sprintf (szTmp, "%s_%ld", szLex, i); /* create names */
+      sprintf(szTmp, "%s_%ld", szLex, i); /* create names */
       /* check this is a declared state */
-      if (GetVarType (pinfo->pvmGloVars, szTmp) != ID_STATE) {
-        sprintf (szTmp, "%s[%ld]", szLex, i); /* recreate name */
-        ReportError (pibIn, RE_BADSTATE | RE_FATAL, szTmp, NULL);
+      if (GetVarType(pinfo->pvmGloVars, szTmp) != ID_STATE) {
+        sprintf(szTmp, "%s[%ld]", szLex, i); /* recreate name */
+        ReportError(pibIn, RE_BADSTATE | RE_FATAL, szTmp, NULL);
       }
-      UnrollEquation (pibIn, i, szEqn, szEqnU);
-      DefineVariable (pibIn, szTmp, szEqnU, iKWCode);
+      UnrollEquation(pibIn, i, szEqn, szEqnU);
+      DefineVariable(pibIn, szTmp, szEqnU, iKWCode);
     }
   }
 
-  if (!GetPunct (pibIn, szLex, CH_STMTTERM))
-    ReportError (pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
+  if (!GetPunct(pibIn, szLex, CH_STMTTERM))
+    ReportError(pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
 
 } /* ProcessDTStatement */
 
@@ -217,53 +217,53 @@ void ProcessIdentifier (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, int iKWCode)
   pinfo = (PINPUTINFO) pibIn->pInfo;
 
   /* check that szLex is less than MAX_NAME characters */
-  if ((i = strlen (szLex)) > MAX_NAME)
-     ReportError (pibIn, RE_NAMETOOLONG | RE_FATAL, szLex, NULL);    
+  if ((i = strlen(szLex)) > MAX_NAME)
+     ReportError(pibIn, RE_NAMETOOLONG | RE_FATAL, szLex, NULL);    
 
-  if (!GetPunct (pibIn, szPunct, '[')) { /* scalar */
+  if (!GetPunct(pibIn, szPunct, '[')) { /* scalar */
     if (szPunct[0] == '=') { /* read assignment */
-      GetStatement (pibIn, szEqn);
-      UnrollEquation (pibIn, 0, szEqn, szEqnU);
-      DefineVariable (pibIn, szLex, szEqnU, iKWCode);
-      if (!GetPunct (pibIn, szLex, CH_STMTTERM))
-        ReportError (pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
+      GetStatement(pibIn, szEqn, iKWCode);
+      UnrollEquation(pibIn, 0, szEqn, szEqnU);
+      DefineVariable(pibIn, szLex, szEqnU, iKWCode);
+      if (!GetPunct(pibIn, szLex, CH_STMTTERM))
+        ReportError(pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
     }
     else if (szPunct[0] == CH_STMTTERM) { /* found a terminator */
       if (pinfo->wContext == CN_GLOBAL) {
         /* in the global section: assign 0; FB 13/6/99 */
-        DefineVariable (pibIn, szLex, "0\0", iKWCode);
+        DefineVariable(pibIn, szLex, "0\0", iKWCode);
       }
       else
-        ReportError (pibIn, RE_LEXEXPECTED | RE_FATAL, "= or [", NULL);
+        ReportError(pibIn, RE_LEXEXPECTED | RE_FATAL, "= or [", NULL);
     }
     else /* nothing recognized: error */
-      ReportError (pibIn, RE_LEXEXPECTED | RE_FATAL, "=, [ or ;", NULL);
+      ReportError(pibIn, RE_LEXEXPECTED | RE_FATAL, "=, [ or ;", NULL);
   } /* end scalar */
 
   else { /* array */
-    GetArrayBounds (pibIn, &iLB, &iUB);
-    if (GetPunct (pibIn, szPunct, '=')) { /* read assignment */
-      GetStatement (pibIn, szEqn);
+    GetArrayBounds(pibIn, &iLB, &iUB);
+    if (GetPunct(pibIn, szPunct, '=')) { /* read assignment */
+      GetStatement(pibIn, szEqn, iKWCode);
       for (i = iLB; i < iUB; i++) {
-        sprintf (szTmp, "%s_%ld", szLex, i); /* create names */
-        UnrollEquation (pibIn, i, szEqn, szEqnU);
-        DefineVariable (pibIn, szTmp, szEqnU, iKWCode);
+        sprintf(szTmp, "%s_%ld", szLex, i); /* create names */
+        UnrollEquation(pibIn, i, szEqn, szEqnU);
+        DefineVariable(pibIn, szTmp, szEqnU, iKWCode);
       }
-      if (!GetPunct (pibIn, szLex, CH_STMTTERM))
-        ReportError (pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
+      if (!GetPunct(pibIn, szLex, CH_STMTTERM))
+        ReportError(pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
     }
     else if (szPunct[0] == CH_STMTTERM) { /* found a terminator */
       if (pinfo->wContext == CN_GLOBAL) { /* in global section assign 0 */
         for (i = iLB; i < iUB; i++) {
-          sprintf (szTmp, "%s_%ld", szLex, i); /* create names */
-          DefineVariable (pibIn, szTmp, "0\0", iKWCode);
+          sprintf(szTmp, "%s_%ld", szLex, i); /* create names */
+          DefineVariable(pibIn, szTmp, "0\0", iKWCode);
         }
       }
       else
-        ReportError (pibIn, RE_LEXEXPECTED | RE_FATAL, "= or [", NULL);
+        ReportError(pibIn, RE_LEXEXPECTED | RE_FATAL, "= or [", NULL);
     }
     else /* nothing recognized: error */
-      ReportError (pibIn, RE_LEXEXPECTED | RE_FATAL, "= or ;", NULL);
+      ReportError(pibIn, RE_LEXEXPECTED | RE_FATAL, "= or ;", NULL);
   } /* end array */
 
 } /* ProcessIdentifier */
@@ -276,15 +276,15 @@ void ProcessIdentifier (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, int iKWCode)
 void ProcessInlineStatement (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn, 
                              int iKWCode)
 {
-  GetStatement (pibIn, szEqn);
+  GetStatement(pibIn, szEqn, iKWCode);
   /* remove leading parenthesis */
   szEqn = szEqn + 1;
   /* remove ending parenthesis */
   szEqn[strlen(szEqn) - 1] = '\0';
-  DefineVariable (pibIn, szLex, szEqn, iKWCode);
+  DefineVariable(pibIn, szLex, szEqn, iKWCode);
 
-  if (!GetPunct (pibIn, szLex, CH_STMTTERM))
-    ReportError (pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
+  if (!GetPunct(pibIn, szLex, CH_STMTTERM))
+    ReportError(pibIn, RE_EXPECTED | RE_FATAL, ";", NULL);
 
 } /* ProcessInlineStatement */
 
@@ -312,14 +312,14 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
 
   pinfo = (PINPUTINFO) pibIn->pInfo;
 
-  iKWCode = GetKeywordCode (szLex, &fContext);
+  iKWCode = GetKeywordCode(szLex, &fContext);
 
-  assert (pinfo->wContext != CN_END);
+  assert(pinfo->wContext != CN_END);
 
   if ((pinfo->wContext == CN_END) ||   /* Beyond valid input ! */
       (iKWCode &&                      /* Is a keyword */
        !(fContext & pinfo->wContext))) /* not in a valid context */
-    ReportError (pibIn, RE_BADCONTEXT | RE_FATAL, szLex, NULL);
+    ReportError(pibIn, RE_BADCONTEXT | RE_FATAL, szLex, NULL);
 
   else {
     switch (iKWCode) {
@@ -331,24 +331,24 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
       case KM_INPUTS:
       case KM_OUTPUTS:
       case KM_COMPARTMENTS:
-        if (GetPunct (pibIn, szPunct, '=')) {
-          if (GetPunct (pibIn, szPunct, CH_LBRACE))
+        if (GetPunct(pibIn, szPunct, '=')) {
+          if (GetPunct(pibIn, szPunct, CH_LBRACE))
             GetVarList(pibIn, szLex, iKWCode);
           else
-            ReportError (pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
+            ReportError(pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
         }
         else
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
         break;
       
       case KM_CALCOUTPUTS:
         if (bCalcOutputsDefined)
-          ReportError (pibIn, RE_DUPSECT | RE_FATAL, "CalcOutputs", NULL);
+          ReportError(pibIn, RE_DUPSECT | RE_FATAL, "CalcOutputs", NULL);
         bCalcOutputsDefined = TRUE;
-        if (!GetPunct (pibIn, szPunct, CH_LBRACE)) {
+        if (!GetPunct(pibIn, szPunct, CH_LBRACE)) {
           szPunct[1] = CH_LBRACE;
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, szPunct,
-                       "* Section must be delimited by curly braces.");
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, szPunct,
+                      "* Section must be delimited by curly braces.");
         }
         else
           pinfo->wContext = KM_TO_CN(iKWCode);
@@ -356,12 +356,12 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
 
       case KM_JACOB:
         if (bJacobianDefined)
-          ReportError (pibIn, RE_DUPSECT | RE_FATAL, "Jacobian", NULL);
+          ReportError(pibIn, RE_DUPSECT | RE_FATAL, "Jacobian", NULL);
         bJacobianDefined = TRUE;
-        if (!GetPunct (pibIn, szPunct, CH_LBRACE)) {
+        if (!GetPunct(pibIn, szPunct, CH_LBRACE)) {
           szPunct[1] = CH_LBRACE;
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, szPunct,
-                       "* Section must be delimited by curly braces.");
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, szPunct,
+                      "* Section must be delimited by curly braces.");
         }
         else
           pinfo->wContext = KM_TO_CN(iKWCode);
@@ -369,12 +369,12 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
 
       case KM_SCALE:
         if (bInitializeDefined)
-          ReportError (pibIn, RE_DUPSECT | RE_FATAL, "Initialize", NULL);
+          ReportError(pibIn, RE_DUPSECT | RE_FATAL, "Initialize", NULL);
         bInitializeDefined = TRUE;
-        if (!GetPunct (pibIn, szPunct, CH_LBRACE)) {
+        if (!GetPunct(pibIn, szPunct, CH_LBRACE)) {
           szPunct[1] = CH_LBRACE;
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, szPunct,
-                       "* Section must be delimited by curly braces.");
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, szPunct,
+                      "* Section must be delimited by curly braces.");
         }
         else
           pinfo->wContext = KM_TO_CN(iKWCode);
@@ -382,10 +382,10 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
 
       case KM_EVENTS:
       case KM_ROOTS:
-        if (!GetPunct (pibIn, szPunct, CH_LBRACE)) {
+        if (!GetPunct(pibIn, szPunct, CH_LBRACE)) {
           szPunct[1] = CH_LBRACE;
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, szPunct,
-                       "* Section must be delimited by curly braces.");
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, szPunct,
+                      "* Section must be delimited by curly braces.");
         }
         else
           pinfo->wContext = KM_TO_CN(iKWCode);
@@ -393,59 +393,59 @@ void ProcessWord (PINPUTBUF pibIn, PSTR szLex, PSTR szEqn)
 
       case KM_DYNAMICS:
         if (bDynamicsDefined)
-          ReportError (pibIn, RE_DUPSECT | RE_FATAL, "Dynamics", NULL);
+          ReportError(pibIn, RE_DUPSECT | RE_FATAL, "Dynamics", NULL);
         bDynamicsDefined = TRUE;
 
-        if (!GetPunct (pibIn, szPunct, CH_LBRACE)) {
+        if (!GetPunct(pibIn, szPunct, CH_LBRACE)) {
           szPunct[1] = CH_LBRACE;
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, szPunct,
-                       "* Section must be delimited by curly braces.");
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, szPunct,
+                      "* Section must be delimited by curly braces.");
         }
         else
           pinfo->wContext = KM_TO_CN(iKWCode);
         break;
 
       case KM_DXDT: /* State equation definition */    
-        ProcessDTStatement (pibIn, szLex, szEqn, iKWCode);
+        ProcessDTStatement(pibIn, szLex, szEqn, iKWCode);
         break;
 
       case KM_INLINE: /* Inline statement definition */    
-        ProcessInlineStatement (pibIn, szLex, szEqn, iKWCode);
+        ProcessInlineStatement(pibIn, szLex, szEqn, iKWCode);
         break;
 
       case KM_SBMLMODELS:
-        if (GetPunct (pibIn, szPunct, '=')) {
-          if (GetPunct (pibIn, szPunct, CH_LBRACE)) {
-            ReadSBMLModels (pibIn);
+        if (GetPunct(pibIn, szPunct, '=')) {
+          if (GetPunct(pibIn, szPunct, CH_LBRACE)) {
+            ReadSBMLModels(pibIn);
           }
           else
-            ReportError (pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
+            ReportError(pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
         }
         else
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
         break;
 
       case KM_PKTEMPLATE:
-        if (GetPunct (pibIn, szPunct, '=')) {
-          if (GetPunct (pibIn, szPunct, CH_LBRACE)) {
-            printf ("\nreading pharmacokinetic template "); 
-            ReadPKTemplate (pibIn);
+        if (GetPunct(pibIn, szPunct, '=')) {
+          if (GetPunct(pibIn, szPunct, CH_LBRACE)) {
+            printf("\nreading pharmacokinetic template "); 
+            ReadPKTemplate(pibIn);
           }
           else
-            ReportError (pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
+            ReportError(pibIn, RE_EXPECTED | RE_FATAL, "{", NULL);
         }
         else
-          ReportError (pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
+          ReportError(pibIn, RE_EXPECTED | RE_FATAL, "=", NULL);
         break;
 
       default: /* Not a keyword, process identifier */
-        ProcessIdentifier (pibIn, szLex, szEqn, iKWCode);
+        ProcessIdentifier(pibIn, szLex, szEqn, iKWCode);
         break;
 
     } /* switch */
 
     if (iErr)
-      EatStatement (pibIn); /* Err in statement, eat to terminator */
+      EatStatement(pibIn); /* Err in statement, eat to terminator */
 
   } /* else */
 
@@ -472,7 +472,7 @@ int FindEnd (PBUF pBuf, long N)
         c++;
       if (c < end) {
 	if (((c+2) < end) && (*c == 'E') && (*(c+1) == 'n') && (*(c+2) == 'd'))
-	  return (1);
+	  return(1);
       }
     }
     c++;
@@ -498,8 +498,8 @@ void ReadModel (PINPUTINFO pinfo, PINPUTINFO ptempinfo, PSTR szFileIn)
   PSTREQN szEqn; /* Equation buffer of MAX_EQN length */
   int iLexType;
 
-  if (!InitBuffer (&ibIn, -1, szFileIn))
-    ReportError (&ibIn, RE_INIT | RE_FATAL, "ReadModel", NULL);
+  if (!InitBuffer(&ibIn, -1, szFileIn))
+    ReportError(&ibIn, RE_INIT | RE_FATAL, "ReadModel", NULL);
 
   /* Attach info records to input buffer */
   ibIn.pInfo = (PVOID) pinfo;
@@ -507,17 +507,17 @@ void ReadModel (PINPUTINFO pinfo, PINPUTINFO ptempinfo, PSTR szFileIn)
 
   /* immediately check whether a valid End is found */
   if (FindEnd(ibIn.pbufOrg, ibIn.lBufSize) == 0)
-    ReportError (NULL, RE_NOEND | RE_FATAL, szFileIn, NULL);
+    ReportError(NULL, RE_NOEND | RE_FATAL, szFileIn, NULL);
 
   do { /* State machine for parsing syntax */
-    NextLex (&ibIn, szLex, &iLexType);
+    NextLex(&ibIn, szLex, &iLexType);
     switch (iLexType) {
       case LX_NULL:
         pinfo->wContext = CN_END;
         break;
 
       case LX_IDENTIFIER:
-        ProcessWord (&ibIn, szLex, szEqn);
+        ProcessWord(&ibIn, szLex, szEqn);
         break;
  
       case LX_PUNCT: case LX_EQNPUNCT:
@@ -532,7 +532,7 @@ void ReadModel (PINPUTINFO pinfo, PINPUTINFO ptempinfo, PSTR szFileIn)
           }
           else {
             if (szLex[0] == CH_COMMENT) {
-              SkipComment (&ibIn);
+              SkipComment(&ibIn);
               break;
             }
             /* else: fall through! */
@@ -540,12 +540,12 @@ void ReadModel (PINPUTINFO pinfo, PINPUTINFO ptempinfo, PSTR szFileIn)
         }
 
       default:
-        ReportError (&ibIn, RE_UNEXPECTED, szLex, "* Ignoring");
+        ReportError(&ibIn, RE_UNEXPECTED, szLex, "* Ignoring");
         break;
  
       case LX_INTEGER:
       case LX_FLOAT:
-        ReportError (&ibIn, RE_UNEXPNUMBER, szLex, "* Ignoring");
+        ReportError(&ibIn, RE_UNEXPNUMBER, szLex, "* Ignoring");
         break; 
 
     } /* switch */
