@@ -1407,7 +1407,7 @@ int Is_numeric(PSTR str)
     return(2);
   }
 
-} /* Is_numeric
+} /* Is_numeric */
 
 
 /* ----------------------------------------------------------------------------
