@@ -39,7 +39,7 @@
 /* ----------------------------------------------------------------------------
    Global/External variables
 */
-#define NTEMP 5
+#define NTEMP 50
 
 
 /* ----------------------------------------------------------------------------
@@ -56,11 +56,19 @@
    Typedefs
 */
 
+/* Specification for PrintTemperatureDiagnostics */
+typedef enum {Geyer, NoGeyer} EGEYER;
+
 
 /* ----------------------------------------------------------------------------
    Prototypes
 */
-
+void   CollectConvInfo (PLEVEL plevel, char **args);
+int    checkConvergence(int nOut, int variableCount,int p_count,
+                        double **meansForAll, double **varsForAll,
+                        double *Rhat);
+void   CalculateMeanAndVariance (long n, double x, double *xi_bari,
+                                 double *si_2i) ;
 void   CalculateTotals (PLEVEL plevel, char **args);
 void   CheckForFixed (PLEVEL plevel, char **args);
 void   CheckPrintStatements (PLEVEL plevel, char **args);
@@ -68,7 +76,7 @@ void   CloneLikes (PLEVEL plevel, char **args);
 void   CloneLikesL (PVOID pData, PVOID pUser1, PVOID pUser2, PVOID pUser3);
 void   CloneMCVars (PLEVEL plevel, char **args);
 void   CloneMCVarsL (PVOID pData, PVOID pUser1, PVOID pUser2, PVOID pUser3);
-void   CloseMarkovFiles (PANALYSIS panal);
+void   CloseMarkovFiles (PGIBBSDATA pgd);
 void   ConvertLists (PLEVEL plevel, char **args);
 void   DoMarkov (PANALYSIS panal);
 void   FindLikeParents (PLEVEL plevel, char **args);
@@ -78,6 +86,7 @@ void   GetNumberOfMCVars (PLEVEL plevel, char **args);
 void   InitArrays (long lDim, long nSubjs, double ***pdSum, 
                    double ****prgdSumProd);
 void   InitMCVars (PLEVEL plevel, char **args);
+void   InitPerks (PANALYSIS panal);
 void   ListToPMCArray (PANALYSIS panal, PLIST plist,
                        long *nMCVars, PMCVAR **rgpMCVars);
 void   ListToPMCArrayL (PVOID pData, PVOID pUser1, PVOID pUser2, PVOID pUser3);
@@ -93,20 +102,22 @@ void   OpenMarkovFiles (PANALYSIS panal);
 void   PrintAllExpts (PLEVEL plevel, PANALYSIS panal, PFILE pOutFile);
 void   PrintDeps (PLEVEL plevel, char **args);
 int    PrintExpt (PLEVEL plevel, char **args);
+void   PrintTemperatureDiagnostics (PFILE fOut, PGIBBSDATA pgd);
 void   ReadData (PLEVEL plevel, char **args);
 void   ReadDataFile (PANALYSIS panal);
 void   ReadKernel (PLEVEL plevel, char **args);
-void   ReadRestart (FILE *pfileRestart, long nThetas, double *pdTheta, 
-                    double *pdSum, double **prgdSumProd, long *pIter);
+void   ReadRestart (FILE *pfileRestart, long nThetas, PDOUBLE *pdTheta, 
+                    PDOUBLE *pdSum, PDOUBLE **prgdSumProd, long *pIter);
 void   ReadRestartTemper (FILE *pfileRestart, long nThetas, 
-                          int nInvTemperatures, double *pdTheta, 
-                          double *pdSum, double **prgdSumProd,
-                          long *pIter, long *pindexT, double *pdlnPi);
+                          int nInvTemperatures, PDOUBLE *pdTheta, 
+                          PDOUBLE *pdSum, PDOUBLE **prgdSumProd,
+                          long *pIter, int *pindexT, double *pdlnPi);
 int    RestoreLikelihoods (PLEVEL plevel, char **args);
 int    RunAllExpts(PANALYSIS panal, PDOUBLE pdLnData);
 int    RunExpt (PLEVEL plevel, char **args);
 double SampleTheta (PMCVAR pMCVar);
 long   SampleTemperature (PGIBBSDATA pgd, double dLnPrior, double dLnData);
+long   SampleTemperature2 (PGIBBSDATA pgd, double dLnPrior, double dLnData);
 void   SampleThetas (PLEVEL plevel, char **args);
 void   SampleThetasTempered (PLEVEL plevel, char **args);
 void   SampleThetaVector (PLEVEL pLevel, PANALYSIS panal, long nThetas,
@@ -138,9 +149,10 @@ void   TraverseLevels (PLEVEL plevel,
                        void (*routinePtr)(PLEVEL plevel, char **args), ...);
 int    TraverseLevels1 (PLEVEL plevel,
                         int (*routinePtr)(PLEVEL plevel, char **args), ...);
-void   WriteHeader (PLEVEL plevel, char **args);
+void   WriteHeader (PANALYSIS panal);
+void   WriteParameterNames (PLEVEL plevel, char **args);
 void   WriteKernel (PLEVEL plevel, char **args);
-void   WriteMCVars (PLEVEL plevel, PFILE pOutFile);
+void   WriteMCVars (PLEVEL plevel, char **args);
 
 #define MH_H_DEFINED
 #endif  /* _MH_H_ */
